SystemOrganization addCategory: #'Ma-Installer-Core'!

Installer subclass: #MaInstaller
	instanceVariableNames: 'host port writeBarrier readStrategy allowLongCatchUp retrySeconds timeoutSeconds'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Ma-Installer-Core'!

MaInstaller class
	instanceVariableNames: 'localRepository'!

!MaInstaller commentStamp: 'cmm 8/3/2012 13:46' prior: 0!
A MaInstaller is a single class capable of installing and configuring Muller Automation software packages.

My 'structures' category defines the dependency-hierarchies of the packages.
!

MaInstaller class
	instanceVariableNames: 'localRepository'!

!MaInstaller class methodsFor: 'class initialization' stamp: 'cmm 8/28/2012 15:49'!
initialize
	self new configure! !

!MaInstaller class methodsFor: 'local-repository' stamp: 'cmm 5/5/2014 18:12'!
local
	^ self localRepository! !

!MaInstaller class methodsFor: 'local-repository' stamp: 'cmm 5/5/2014 18:02'!
localRepository
	^ localRepository ifNil: [ Installer monticello directory: FileDirectory default / 'mc' ]! !

!MaInstaller class methodsFor: 'local-repository' stamp: 'cmm 4/28/2014 15:34'!
localRepository: aMCRepository 
	localRepository := aMCRepository! !

!MaInstaller class methodsFor: 'repository-overrides' stamp: 'cmm 5/7/2014 14:02'!
suspendRepositoryOverridesWhile: aBlock 
	| priorOverrides |
	[ priorOverrides := Repositories.
	self clearOverrides.
	aBlock value ] ensure: [ Repositories := priorOverrides ]! !

!MaInstaller class methodsFor: 'local-repository' stamp: 'cmm 5/5/2014 17:44'!
useLocalRepository
	self overrideRemoteRepostoriesWith: #local! !

!MaInstaller methodsFor: 'private' stamp: 'cmm 5/8/2014 20:55'!
addRemoteRepositories
	self allPackages do:
		[ : each | self class suspendRepositoryOverridesWhile:
			[ self
				addRemoteRepositoryFor: each
				id: String empty
				password: String empty ] ]! !

!MaInstaller methodsFor: 'private' stamp: 'cmm 4/28/2014 19:43'!
addRemoteRepositoriesId: idString password: pwString
	"Adding all these to MCRepositoryGroup default causes it to go to those and ask for passwords when doing some regular MC operations."
	self allPackages do:
		[ : eachSelector | self
			depthFirstOf: (self perform: eachSelector)
			do:
				[ : each | each isVariableBinding ifTrue:
					[ MCRepositoryGroup default addRepository:
						((self class defaultRepositoryFor: each)
							 user: idString ;
							 password: pwString ;
							 yourself) ] ] ]! !

!MaInstaller methodsFor: 'configure' stamp: 'cmm 5/8/2014 20:46'!
addRemoteRepositoryFor: structureOrSymbol id: idString password: pwString 
	structureOrSymbol isSymbol
		ifTrue:
			[ self
				addRemoteRepositoryFor: (self perform: structureOrSymbol)
				id: idString
				password: pwString ]
		ifFalse:
			[ self
				depthFirstOf: structureOrSymbol
				do:
					[ : each | each isVariableBinding
						ifTrue: [ currentRepository := self class repositoryFor: each ]
						ifFalse:
							[ each isString
								ifTrue:
									[ MCWorkingCopy allManagers
										detect:
											[ : eachWorkingCopy | eachWorkingCopy packageName = each ]
										ifFound:
											[ : foundWorkingCopy | foundWorkingCopy repositoryGroup addRepository: currentRepository ]
										ifNone: [  ] ]
								ifFalse: [ self error: 'invalid specification' ] ] ] ]! !

!MaInstaller methodsFor: 'lists' stamp: 'cmm 9/27/2012 17:15'!
allApplications
	^ self class methodsInCategory: 'applications'! !

!MaInstaller methodsFor: 'magma' stamp: 'cmm 9/11/2012 16:31'!
allLocations
	| locations |
	locations := OrderedCollection new.
	{self hosts. 
	self ports} maPermutationsDo:
		[ : eachHostAndPort | locations add:
			(self
				locationAt: eachHostAndPort first
				port: eachHostAndPort second) ].
	^ locations sort: [ : a : b | a host < b host ]! !

!MaInstaller methodsFor: 'lists' stamp: 'cmm 7/10/2014 12:54'!
allPackages
	"Duplicate this method from my superclass to support Squeak 4.5.  Eventually, it can be removed."
	^ (self class withAllSuperclasses
		inject: OrderedCollection new
		into:
			[ : coll : each | coll
				 addAll: (each methodsInCategory: 'package-definitions') ;
				 yourself ]) sort! !

!MaInstaller methodsFor: 'configure' stamp: 'cmm 8/7/2014 17:11'!
allowLongCatchUp: aBoolean
	allowLongCatchUp := aBoolean! !

!MaInstaller methodsFor: 'package-definitions' stamp: 'cmm 8/8/2013 20:45'!
banyan
	^ {self base. 
	self osProcess. 
	#ss3 -> 'Banyan'.
	'Banyan'}! !

!MaInstaller methodsFor: 'package-definitions' stamp: 'cmm 9/27/2012 17:11'!
banyanMaui
	^ {self banyan. 
	self maUi.
	'Banyan.MauiFamily'}! !

!MaInstaller methodsFor: 'package-definitions' stamp: 'cmm 5/5/2014 20:15'!
base
	^ { #ss3 -> 'MaBase'.
	'Ma-Core'.
	'Ma-Squeak-Core'.
	'BrpExtensions'.
	'Collections-BTree'.
	'Ma-Search'.
	'Ma-Collections'.
	'Ma-Ascii-Report'.
	'Ma-Statistics' }! !

!MaInstaller methodsFor: 'magma' stamp: 'cmm 5/22/2013 16:57'!
chasePointerToAnyLocalMagmaSession
	(Smalltalk classNamed: #MagmaSession) ifNotNil:
		[ : magmaSession | magmaSession allInstances do:
			[ : each | each isLocal ifTrue: [ self chasePointerToMagmaSession: each ] ] ]! !

!MaInstaller methodsFor: 'magma' stamp: 'cmm 5/22/2013 16:58'!
chasePointerToAnyMagmaSession
	(Smalltalk classNamed: #MagmaSession)
		ifNil: [ self error: 'Magma not installed' ]
		ifNotNil:
			[ : magmaSession | self chasePointerToMagmaSession: magmaSession allInstances atRandom ]! !

!MaInstaller methodsFor: 'magma' stamp: 'cmm 5/22/2013 16:57'!
chasePointerToMagmaSession: aMagmaSession 
	(Smalltalk classNamed: #MagmaPreferences) debugProxiesWhile: [ aMagmaSession chasePointers ]! !

!MaInstaller methodsFor: 'package-definitions' stamp: 'cmm 8/8/2013 20:44'!
clientServer
	^ { self serializer.
	self osProcess.
	#ss3 -> 'Ma-Client-Server'.
	'Ma-Client-Server-Core' }! !

!MaInstaller methodsFor: 'package-definitions' stamp: 'cmm 5/5/2014 22:23'!
clientServerTester
	^ { self clientServer.
	#ss3 -> 'Ma-Client-Server'.
	'Ma-Client-Server-Tester' }! !

!MaInstaller methodsFor: 'api' stamp: 'cmm 3/8/2014 15:01'!
close: anObject 
	"Close down all windows for the same database as anObject.  Remove any open MauiMorphs whose objects were retrieved from the same magmaSession as for anObject."
	| sess |
	sess := anObject magmaSession.
	sess ifNil: [ ^ anObject ].
	"ensureConnected so that quickMagmaSession is sure to work."
	sess isConnected ifFalse: [ sess ensureConnected ].
	(Smalltalk classNamed: #MauiWorld) current playersDo:
		[ : each | each object quickMagmaSession = sess ifTrue: [ each delete ] ].
	sess disconnectAndClose! !

!MaInstaller methodsFor: 'configure' stamp: 'cmm 5/7/2014 13:51'!
configure
	(self confirm: 'Configure to load from your local repository instead of remote repositories?')
		ifTrue: [ self class useLocalRepository ]
		ifFalse: [ self addRemoteRepositories ].
	self merge: self systemModifications.
	(self confirm: 'Load installer Maui interface?') ifTrue:
		[ self
			 merge: #installerMaui ;
			 maui ]! !

!MaInstaller methodsFor: 'private' stamp: 'cmm 9/27/2012 17:49'!
configureUsing: arrayOfAssociations 
	"Configure this object with the specified key-value associations."
	arrayOfAssociations do:
		[ : each | each isVariableBinding
			ifTrue:
				[ self
					perform: each key
					with: each value ]
			ifFalse:
				[ each isArray ifTrue: [ self configureUsing: each ] ] ]! !

!MaInstaller methodsFor: 'private' stamp: 'cmm 8/2/2012 22:06'!
currentInfoForPackageNamed: aString 
	^ (MCWorkingCopy allManagers
		detect: [ : each | each packageName = aString ]
		ifNone: [ self error: 'This operation requires the packages to be loaded.' ]) ancestors anyOne! !

!MaInstaller methodsFor: 'configure' stamp: 'cmm 4/3/2013 17:12'!
deleteAllWindows
	(SystemWindow
		windowsIn: ActiveWorld
		satisfying:
			[ : window | true ]) do:
				[ : window | [ window makeClosable; delete ]
					on: ProvideAnswerNotification
					do: [ : noti | noti resume: true ] ]! !

!MaInstaller methodsFor: 'configure' stamp: 'cmm 8/9/2012 20:19'!
host: aString
	host := aString! !

!MaInstaller methodsFor: 'machines' stamp: 'cmm 2/20/2014 10:59'!
hosts
	"Subclasses override."
	^ Array empty! !

!MaInstaller methodsFor: 'package-definitions' stamp: 'cmm 5/5/2014 21:00'!
htmlParser
	^ { #ss3 -> 'htmlcssparser'. 
	'HTML' }! !

!MaInstaller methodsFor: 'initialize-release' stamp: 'cmm 11/16/2014 14:25'!
initialize
	super initialize.
	writeBarrier := true.
	allowLongCatchUp := true.
	timeoutSeconds := retrySeconds := 30! !

!MaInstaller methodsFor: 'package-definitions' stamp: 'cmm 3/7/2013 13:11'!
installerMaui
	"Maui framework + the UI panel for MaInstaller itself."
	^ {self maUi. 
	'Ma-Installer-Core.MauiFamily'}! !

!MaInstaller methodsFor: 'private' stamp: 'cmm 8/27/2012 19:58'!
location
	^ (Smalltalk classNamed: #MagmaRemoteLocation)
		ifNil: [ self error: 'MaInstaller problem.  Magma-Client must be installed before this can be done.' ]
		ifNotNil:
			[ : locationClass | locationClass
				host: host
				port: port ]! !

!MaInstaller methodsFor: 'private' stamp: 'cmm 12/19/2013 21:33'!
locationAt: hostString port: portNumber 
	^ (Smalltalk classNamed: #MagmaRemoteLocation)
		ifNil:
			[ Warning signal: 'Magma-Client must be loaded to do this.  Magma-Client will now be loaded.'.
			self
				 merge: #magmaClient ;
				
				locationAt: hostString
				port: portNumber ]
		ifNotNil:
			[ : cls | cls
				host: hostString
				port: portNumber ]! !

!MaInstaller methodsFor: 'package-definitions' stamp: 'cmm 5/7/2014 20:39'!
maUi
	"We can't name this maui because that's needed to maui the receiver!!"
	^ {self serializer. 
	self connectors.
	#ss3 -> 'Maui'.
	'Maui-Core'.
	'Maui-Core.MauiFamily'.
	'Kernel.MauiFamily'.
	'Collections.MauiFamily'.
	'PackageInfo-Base.MauiFamily'.
	'Ma-Core.MauiFamily'.
	'Ma-Search.MauiFamily'.
	'Ma-Statistics.MauiFamily' }! !

!MaInstaller methodsFor: 'magma' stamp: 'cmm 2/2/2013 17:38'!
magmaCleanUp
	^ (Smalltalk classNamed: #MagmaSession) ifNotNil:
		[ : magmaSession | magmaSession cleanUp ]! !

!MaInstaller methodsFor: 'package-definitions' stamp: 'cmm 8/20/2014 15:38'!
magmaClient
	^ {self clientServer.
	self plotMorph.
	#ss3 -> 'Magma'.
	'WriteBarrier'. 
	'SOLHashTables'.
	'Magma-Client'. 
	'Magma-Squeak-Client'}! !

!MaInstaller methodsFor: 'package-definitions' stamp: 'cmm 9/27/2012 17:11'!
magmaClientMaui
	^ { self magmaClient.
	self maUi.
	'Magma-Client.MauiFamily' }! !

!MaInstaller methodsFor: 'package-definitions' stamp: 'cmm 5/5/2014 22:25'!
magmaServer
	^ {self magmaClient.
	#ss3 -> 'Magma'.
	'Magma-Server'}! !

!MaInstaller methodsFor: 'magma' stamp: 'cmm 3/2/2013 11:56'!
magmaSessionInstances
	^ (Smalltalk classNamed: #MagmaSession)
		ifNil: [ Array empty ]
		ifNotNil: [ : magmaSession | magmaSession allInstances ]! !

!MaInstaller methodsFor: 'package-definitions' stamp: 'cmm 5/5/2014 20:32'!
magmaTester
	^ {self magmaServer.
	self clientServerTester.
	self serializerTests.
	#ss3 -> 'Magma'.
	'Magma-Tester'}! !

!MaInstaller methodsFor: 'package-definitions' stamp: 'cmm 5/5/2014 22:26'!
magmaTools
	^ { self magmaServer.
	#ss3 -> 'Magma'.
	'Magma-Tools' }! !

!MaInstaller methodsFor: 'private' stamp: 'cmm 9/27/2012 17:32'!
mauiDefaultView
	^ 'Main'! !

!MaInstaller methodsFor: 'private' stamp: 'cmm 8/27/2012 19:46'!
mergeMauiFamily: filename 
	(Smalltalk classNamed: #MauiFamily)
		ifNil: [ self error: 'Problem with MaInstaller.  Maui must be installed before ' , filename , ' can be.' ]
		ifNotNil:
			[ : mauiFamilyClass | (self projectDirectoryFor: filename) in:
				[ : dir | (dir fileExists: filename)
					ifTrue: [ mauiFamilyClass fileInFileNamed: (dir fullNameFor: filename) ]
					ifFalse: [ self warnNotFound: filename ] ] ]! !

!MaInstaller methodsFor: 'private' stamp: 'cmm 2/20/2014 13:04'!
newSession
	| sess |
	sess := self location newSession
		 connectAs: Utilities authorInitials , '@' , (FileDirectory localNameFor: Smalltalk imageName) ;
		 yourself.
	readStrategy ifNotNil: [ sess readStrategy: readStrategy ].
	^ sess! !

!MaInstaller methodsFor: 'api' stamp: 'cmm 11/16/2014 14:42'!
open: applicationName 
	"Merge all packages and present the root object of the specified application (from the client-uis protocol)."
	| session object |
	self configureUsing:
		(applicationName isSymbol
			ifTrue: [ self perform: applicationName asSymbol ]
			ifFalse: [ applicationName ]).
	session := self newSession
		 allowWriteBarrier: writeBarrier ;
		 allowLongCatchUp: allowLongCatchUp ;
		 retrySeconds: timeoutSeconds ;
		 timeoutSeconds: timeoutSeconds ;
		 yourself.
	object := session root.
	object validateDomainVersion.
	(Smalltalk hasClassNamed: #MauiDomainMorph)
		ifTrue:
			[ | widget |
			widget := object maui.
			widget notificationHandler: session ]
		ifFalse: [ session root inspect ]! !

!MaInstaller methodsFor: 'lists' stamp: 'cmm 11/27/2012 15:09'!
packagesFor: structureOrSymbol 
	^ Array streamContents:
		[ : stream | self
			depthFirstOf:
				(structureOrSymbol isSymbol
					ifTrue: [ self perform: structureOrSymbol ]
					ifFalse: [ structureOrSymbol ])
			do:
				[ : each | stream nextPut: each ] ]! !

!MaInstaller methodsFor: 'package-definitions' stamp: 'cmm 5/5/2014 20:39'!
plotMorph
	^ { #ss3 -> 'PlotMorph'.
	'PlotMorph' }! !

!MaInstaller methodsFor: 'configure' stamp: 'cmm 8/9/2012 19:29'!
port: anInteger
	port := anInteger! !

!MaInstaller methodsFor: 'machines' stamp: 'cmm 2/20/2014 10:59'!
ports
	"Subclasses override."
	^ Array empty! !

!MaInstaller methodsFor: 'private' stamp: 'cmm 11/11/2013 14:38'!
primMerge: packageName 
	(packageName endsWith: '.MauiFamily')
		ifTrue: [ self mergeMauiFamily: packageName ]
		ifFalse: [ super primMerge: packageName ]! !

!MaInstaller methodsFor: 'private' stamp: 'cmm 8/3/2012 15:53'!
projectDirectoryFor: filename
	"Someday might want to parse up to the first dot of filename to identify a 'project' directory.  Until then, just the default dir since that's how I work."
	^ FileDirectory default! !

!MaInstaller methodsFor: 'configure' stamp: 'cmm 1/1/2015 22:15'!
readStrategy: selectorSymbol 
	readStrategy := selectorSymbol isSymbol
		ifTrue: [ self perform: selectorSymbol ]
		ifFalse: [ "allow passing in a ReadStrategy directly"
			selectorSymbol ]! !

!MaInstaller methodsFor: 'configure' stamp: 'cmm 11/16/2014 14:47'!
retrySeconds: anInteger
	retrySeconds := anInteger! !

!MaInstaller methodsFor: 'magma' stamp: 'cmm 12/19/2013 21:32'!
runMagmaTestSuite
	^ (Smalltalk classNamed: #MagmaTestCase)
		ifNil:
			[ Warning signal: 'The magmaTester package must be loaded to do this.  It will be loaded now.'.
			self
				 merge: #magmaTester ;
				 runMagmaTestSuite ]
		ifNotNil:
			[ : magmaTestCase | [ magmaTestCase suite debug ]
				on: (Smalltalk classNamed: #MagmaWarning)
				do: [ : warn | warn resume ] ]! !

!MaInstaller methodsFor: 'package-definitions' stamp: 'cmm 8/7/2012 20:29'!
serializer
	^ {self base. 
	'Ma-Serializer-Core'. 
	'Ma-Serializer-Squeak-Core'}! !

!MaInstaller methodsFor: 'package-definitions' stamp: 'cmm 5/7/2014 09:49'!
serializerTests
	^ {self serializer.
	#ss3 -> 'MaBase'.
	'Ma-Serializer-Tests'}! !

!MaInstaller methodsFor: 'package-definitions' stamp: 'cmm 2/20/2014 11:18'!
systemModifications
	"Enhanced versions of base packages.  Include my own package in case there has been an updated version saved into the repository.
	Subclasses override."
	^ Array empty! !

!MaInstaller methodsFor: 'configure' stamp: 'cmm 11/16/2014 14:47'!
timeoutSeconds: anInteger
	timeoutSeconds := anInteger! !

!MaInstaller methodsFor: 'private' stamp: 'cmm 8/3/2012 16:00'!
warnNotFound: filename 
	Warning signal: ((self projectDirectoryFor: filename) fullNameFor: filename) , ' not found.  Those Maui panels were not loaded.'! !

!MaInstaller methodsFor: 'configure' stamp: 'cmm 8/9/2012 19:29'!
writeBarrier: aBoolean
	writeBarrier:=aBoolean! !

!SHTextStylerST80 class methodsFor: '*ma-installer-core' stamp: 'cmm 12/3/2012 16:21'!
blackOnWhiteStyleTable
	"color can be a valid argument to Color class>>colorFrom: , or nil to
	use the editor text color.
	Multiple emphases can be specified using an array e.g. #(bold italic).
	If emphasis is not specified, #normal will be used.
	if pixel height is not specified , then the editor font size will be used.
	"
								
^#(
	"(symbol	color		[emphasisSymbolOrArray		[textStyleName [pixelHeight]]])"		
	(default 								black 		)
	(invalid 								(magenta twiceDarker) 			)
	(excessCode 								(magenta twiceDarker) 			)
	(comment 								(gray)   italic)
	(unfinishedComment 					(gray)	italic)
	(#'$'									(black) 	)
	(character								(red twiceDarker ) 	)
	(integer									(red twiceDarker ) 	)
	(number								(red twiceDarker ) 	)	
	(#-										(black) 	)
	(symbol									(black )	)	
	(stringSymbol							(black )		)	
	(literalArray								(black )			)
	(string									(red twiceDarker)	normal		)
	(unfinishedString						red			normal		)
	(assignment								black			bold		)
	(ansiAssignment 						black			bold)
	(literal									(red twiceDarker)			italic)
	(keyword								(green muchDarker)			)
	(binary 									(black )			(bold))	
	(unary									(green muchDarker )			)
	(incompleteKeyword						(green darker)			underlined)
	(incompleteBinary 						(green darker)			underlined)	
	(incompleteUnary						(green darker)			underlined)
	(undefinedKeyword					(magenta twiceDarker)			)
	(undefinedBinary 						(magenta twiceDarker)			)	
	(undefinedUnary						(magenta twiceDarker)			)													
	(patternKeyword 						(green muchDarker)			(underlined bold))
	(patternBinary 						(green muchDarker)			(bold))
	(patternUnary							(green muchDarker)			(underlined bold))	
	(#self 									(black)	bold)
	(#super									(black)	bold) 
	(#true 									(black)	bold)
	(#false 									(black)	bold)
	(#nil 									(black)	bold)
	(#thisContext 							(black)	bold)
	(#return								(black)					bold)
	(patternArg 							(orange muchDarker)			)	
	(methodArg 							(orange muchDarker)			)
	(blockPatternArg 						(orange muchDarker)			)
	(blockArg 								(orange muchDarker)			)
	(argument 								(orange muchDarker)			)
	(blockArgColon							black		) 
	(leftParenthesis							black		) 
	(rightParenthesis						black		) 
	(leftParenthesis1						(black)		) 
	(rightParenthesis1						(black)		) 
	(leftParenthesis2						(gray twiceDarker)		) 
	(rightParenthesis2						(gray twiceDarker)		) 
	(leftParenthesis3						(blue twiceDarker)		) 
	(rightParenthesis3						(blue twiceDarker)		) 
	(leftParenthesis4						(green twiceDarker)		) 
	(rightParenthesis4						(green twiceDarker)		) 
	(leftParenthesis5						(orange twiceDarker)		) 
	(rightParenthesis5						(orange twiceDarker)		) 
	(leftParenthesis6						(red twiceDarker)		) 
	(rightParenthesis6						(red twiceDarker)		) 
	(leftParenthesis7						brown		) 
	(rightParenthesis7						brown		) 
	(blockStart 								black		) 
	(blockEnd 								black		) 
	(blockStart1								(black)			) 
	(blockEnd1								(black)			) 
	(blockStart2								(gray twiceDarker)		) 
	(blockEnd2								(gray twiceDarker)		) 
	(blockStart3								(blue twiceDarker)		) 
	(blockEnd3								(blue twiceDarker)		) 
	(blockStart4								(green twiceDarker)		) 
	(blockEnd4								(green twiceDarker)		) 
	(blockStart5								(orange twiceDarker)		) 
	(blockEnd5								(orange twiceDarker)		) 
	(blockStart6								(red twiceDarker)		) 
	(blockEnd6								(red twiceDarker)		) 
	(blockStart7								(brown)		) 
	(blockEnd7								(brown)		) 																																																		
	(arrayStart								black		) 
	(arrayEnd								black		) 
	(arrayStart1							black		) 
	(arrayEnd1								black		) 
	(leftBrace 								black		) 
	(rightBrace 								black		) 
	(cascadeSeparator 						black		) 
	(statementSeparator 						black		) 
	(externalCallType 						black		) 
	(externalCallTypePointerIndicator 		black		) 
	(primitiveOrExternalCallStart 			black		) 
	(primitiveOrExternalCallEnd				black		)
	(methodTempBar						black		) 
	(blockTempBar 							black		)
	(blockArgsBar							black		)
	(primitive								(green muchDarker)		bold)
	(externalFunctionCallingConvention		(green muchDarker)		bold) 
	(module									(green muchDarker)		bold)
	(blockTempVar 							(cyan muchDarker )		italic)
	(blockPatternTempVar					(cyan muchDarker )		italic)
	(instVar 								(yellow twiceDarker darker)		bold)
	(workspaceVar							black		bold)
	(undefinedIdentifier						(magenta twiceDarker)	normal)
	(incompleteIdentifier						(gray darker) 	(italic underlined))
	(tempVar								(cyan muchDarker)	italic)
	(patternTempVar						(cyan muchDarker)	italic)
	(poolConstant							(blue lighter)	italic)
	(classVar								(blue twiceLighter)	italic)
	(globalVar								black		normal) )
! !

!SHTextStylerST80 class methodsFor: '*ma-installer-core' stamp: 'cmm 12/3/2012 16:22'!
whiteOnBlackStyleTable
	"color can be a valid argument to Color class>>colorFrom: , or nil to
	use the editor text color.
	Multiple emphases can be specified using an array e.g. #(bold italic).
	If emphasis is not specified, #normal will be used.
	if pixel height is not specified , then the editor font size will be used.
	"
								
^#(
	"(symbol	color		[emphasisSymbolOrArray		[textStyleName [pixelHeight]]])"		
	(default 								white 		)
	(invalid 								red 			)
	(excessCode 								red 			)
	(comment 								(gray)   italic)
	(unfinishedComment 					(gray)	italic)
	(#'$'									(white) 	)
	(character								(red ) 	)
	(integer									(red ) 	)
	(number								(red ) 	)	
	(#-										(white) 	)
	(symbol									(white )	)	
	(stringSymbol							(white )		)	
	(literalArray								(white )			)
	(string									(red)	normal		)
	(unfinishedString						magenta			normal		)
	(assignment								white			bold		)
	(ansiAssignment 						white			bold)
	(literal									red			italic)
	(keyword								(green )			)
	(binary 									(white )			(bold))	
	(unary									(green )			)
	(incompleteKeyword						(green muchDarker)			underlined)
	(incompleteBinary 						(green muchDarker)			underlined)	
	(incompleteUnary						(green muchDarker)			underlined)
	(undefinedKeyword						magenta			)
	(undefinedBinary 						magenta			)	
	(undefinedUnary							magenta			)													
	(patternKeyword 						(green)			(underlined bold))
	(patternBinary 							(green)			(bold))
	(patternUnary							(green)			(underlined bold))	
	(#self 									(white)	bold)
	(#super									(white)	bold) 
	(#true 									(white)	bold)
	(#false 									(white)	bold)
	(#nil 									(white)	bold)
	(#thisContext 							(white)	bold)
	(#return								(white)					bold)
	(patternArg 								(cyan)			)	
	(methodArg 							(cyan)			)
	(blockPatternArg 						(cyan)			)
	(blockArg 								(cyan)			)
	(argument 								(cyan)			)
	(blockArgColon							white		) 
	(leftParenthesis							white		) 
	(rightParenthesis						white		) 
	(leftParenthesis1						(white)		) 
	(rightParenthesis1						(white)		) 
	(leftParenthesis2						(yellow twiceLighter)		) 
	(rightParenthesis2						(yellow twiceLighter)		) 
	(leftParenthesis3						(green muchLighter)		) 
	(rightParenthesis3						(green muchLighter)		) 
	(leftParenthesis4						(orange)		) 
	(rightParenthesis4						(orange)		) 
	(leftParenthesis5						(red muchLighter)		) 
	(rightParenthesis5						(red muchLighter)		) 
	(leftParenthesis6						(palePeach)		) 
	(rightParenthesis6						(palePeach)		) 
	(leftParenthesis7						blue		) 
	(rightParenthesis7						blue		) 
	(blockStart 								white		) 
	(blockEnd 								white		) 
	(blockStart1								(white)			) 
	(blockEnd1								(white)			) 
	(blockStart2								(yellow twiceLighter)		) 
	(blockEnd2								(yellow twiceLighter)		) 
	(blockStart3								(green muchLighter)		) 
	(blockEnd3								(green muchLighter)		) 
	(blockStart4								(orange)		) 
	(blockEnd4								(orange)		) 
	(blockStart5								(red muchLighter)		) 
	(blockEnd5								(red muchLighter)		) 
	(blockStart6								(palePeach)		) 
	(blockEnd6								(palePeach)		) 
	(blockStart7								(blue)		) 
	(blockEnd7								(blue)		) 																																																		
	(arrayStart								white		) 
	(arrayEnd								white		) 
	(arrayStart1							white		) 
	(arrayEnd1								white		) 
	(leftBrace 								white		) 
	(rightBrace 								white		) 
	(cascadeSeparator 						white		) 
	(statementSeparator 						white		) 
	(externalCallType 						white		) 
	(externalCallTypePointerIndicator 		white		) 
	(primitiveOrExternalCallStart 			white		) 
	(primitiveOrExternalCallEnd				white		)
	(methodTempBar						white		) 
	(blockTempBar 							white		)
	(blockArgsBar							white		)
	(primitive								(green muchDarker)		bold)
	(externalFunctionCallingConvention		(green muchDarker)		bold) 
	(module									(green muchDarker)		bold)
	(blockTempVar 							(cyan )		italic)
	(blockPatternTempVar					(cyan )		italic)
	(instVar 								(yellow twiceDarker)		bold)
	(workspaceVar							white		bold)
	(undefinedIdentifier						magenta	bold)
	(incompleteIdentifier						(gray darker) 	(italic underlined))
	(tempVar								(cyan muchDarker)	italic)
	(patternTempVar						(cyan muchDarker)	italic)
	(poolConstant							(blue lighter)	italic)
	(classVar								(blue twiceLighter)	italic)
	(globalVar								blue		bold) )
! !
MaInstaller initialize!
